@@ -29,7 +29,7 @@
 """
 This package contains the protocols and data for crYOLO
 """
-import pyworkflow.em
+import pwem
 import pyworkflow.utils as pwutils
 import pyworkflow as pw
 from sphire.constants import *
@@ -38,10 +38,8 @@ _logo = "sphire_logo.png"
 _sphirePluginDir = os.path.dirname(os.path.abspath(__file__))
 
 
-class Plugin(pyworkflow.em.Plugin):
-    _cryoloVersion = None  # Means not detected yet
-    _cryoloVersionSupported = None
-    _condaActivationCmd = None
+class Plugin(pwem.Plugin):
+
     @classmethod
     def _defineVariables(cls):
         # CRYOLO do NOT need EmVar because it uses a conda environment.
@@ -76,75 +74,15 @@ class Plugin(pyworkflow.em.Plugin):
         if 'PYTHONPATH' in environ:
             # this is required for python virtual env to work
             del environ['PYTHONPATH']
+        cudaLib = environ.get(CRYOLO_CUDA_LIB, pwem.Config.CUDA_LIB)
+        environ.addLibrary(cudaLib)
         return environ
 
-    #Ignore validateInstallation and __parseCryoloVersion due to the decrease in performance. Although they are functional.
-    # @classmethod
-    # def validateInstallation(cls):
-    #     """
-    #     Check we can activate the crYOLO environment using the provided
-    #     command via variable CRYOLO_ENV_ACTIVATION and the version can be
-    #     parsed.
-    #     """
-    #     errors = []
-    #     cls.__parseCryoloVersion()
-    #
-    #     if cls._cryoloVersion is None:
-    #         errors.append("crYOLO environment could not be activated.\n"
-    #                       "or the version could not be parsed. \n"
-    #                       "Using %s=%s" % (CRYOLO_ENV_ACTIVATION,
-    #                                        cls.getCryoloEnvActivation()))
-    #     elif not cls._cryoloVersionSupported:
-    #         errors.append("crYOLO version %s unsupported" % cls._cryoloVersion)
-    #
-    #     return errors
-    #
-    # @classmethod
-    # def __parseCryoloVersion(cls):
-    #     # If the version has not been detected, try to load the environment
-    #     if cls._cryoloVersionSupported is None:
-    #         try:
-    #             # check if is crYOLO is installed or not
-    #             cmd = cls.getCryoloEnvActivation()
-    #             cmd += '; pip list | grep cryolo'
-    #             p = subprocess.Popen(["bash", "-c", cmd], env=cls.getEnviron(),
-    #                                  stdin=subprocess.PIPE, stdout=subprocess.PIPE)
-    #             output, err = p.communicate()
-    #             cls._cryoloVersion = output.split()[1]
-    #             from pkg_resources import parse_version
-    #             cls._cryoloVersionSupported = parse_version(cls._cryoloVersion) >= parse_version("1.2")
-    #         except Exception as e:
-    #             cls._cryoloVersion = None
-    #             cls._cryoloVersionSupported = False
-    @classmethod
-    def getCondaActivationCmd(cls):
-
-        if cls._condaActivationCmd is None:
-            condaActivationCmd = os.environ.get(CONDA_ACTIVATION_CMD_VAR, "")
-            correctCondaActivationCmd = condaActivationCmd.replace(pw.Config.SCIPION_HOME + "/", "")
-            if not correctCondaActivationCmd:
-                print("WARNING!!: %s variable not defined. "
-                       "Relying on conda being in the PATH" % CONDA_ACTIVATION_CMD_VAR)
-            elif correctCondaActivationCmd[-1] not in [";", "&"]:
-                correctCondaActivationCmd += "&&"
-
-            cls._condaActivationCmd = correctCondaActivationCmd
-
-        return cls._condaActivationCmd
-
     @classmethod
     def defineBinaries(cls, env):
 
         cls.addCryoloPackage(env, CRYOLO_DEFAULT_VER_NUM, default=bool(cls.getCondaActivationCmd()))
 
-        env.addPackage(CRYOLO_GENMOD, version=CRYOLO_GENMOD_202002_N63,
-                       tar='void.tgz',
-                       commands=[(
-                                 "wget ftp://ftp.gwdg.de/pub/misc/sphire/crYOLO-GENERAL-MODELS/" +
-                                 CRYOLO_GENMOD_202002_N63_FN, CRYOLO_GENMOD_202002_N63_FN)],
-                       neededProgs=["wget"],
-                       default=True)
-
         env.addPackage(CRYOLO_GENMOD, version=CRYOLO_GENMOD_201910,
                        tar='void.tgz',
                        commands=[(
@@ -153,6 +91,14 @@ class Plugin(pyworkflow.em.Plugin):
                        neededProgs=["wget"],
                        default=False)
 
+        env.addPackage(CRYOLO_GENMOD, version=CRYOLO_GENMOD_202002_N63,
+                       tar='void.tgz',
+                       commands=[(
+                                 "wget ftp://ftp.gwdg.de/pub/misc/sphire/crYOLO-GENERAL-MODELS/" +
+                                 CRYOLO_GENMOD_202002_N63_FN, CRYOLO_GENMOD_202002_N63_FN)],
+                       neededProgs=["wget"],
+                       default=True)
+
         env.addPackage(CRYOLO_NS_GENMOD, version=CRYOLO_NS_GENMOD_20190226,
                        tar='void.tgz',
                        commands=[(
@@ -219,5 +165,3 @@ class Plugin(pyworkflow.em.Plugin):
         fullProgram = '%s %s && %s' % (cls.getCondaActivationCmd(), cls.getCryoloEnvActivation(), program)
         protocol.runJob(fullProgram, args, env=cls.getEnviron(), cwd=cwd)
 
-
-pyworkflow.em.Domain.registerPlugin(__name__)
