@@ -30,11 +30,10 @@ import csv
 import re
 
 import pyworkflow.object as pwobj
-import pyworkflow.em as emobj
+import pwem.objects as emobj
+from pwem.emlib.image import ImageHandler
 import pyworkflow.utils as pwutils
-from pyworkflow.em import ImageHandler
-from pyworkflow.em.convert import Ccp4Header
-from pyworkflow.utils.path import createAbsLink, getExt
+from pwem.convert import Ccp4Header
 
 import sphire.constants as constants
 
@@ -186,7 +185,7 @@ def readMicrographCoords(mic, coordSet, coordsFile, boxSize, yFlipHeight=None, b
         coord.setObjId(None)
         coord.setPosition(x, y)
         coord.setMicrograph(mic)
-        coord._cryoloScore = emobj.Float(score)
+        coord._cryoloScore = pwobj.Float(score)
         # Add it to the set
         coordSet.append(coord)
 
@@ -195,7 +194,7 @@ def readMicrographCoords(mic, coordSet, coordsFile, boxSize, yFlipHeight=None, b
 
 def needToFlipOnY(filename):
     """ Returns true if need to flip coordinates on Y"""
-    ext = getExt(filename)
+    ext = pwutils.getExt(filename)
 
     if ext in ".mrc":
         header = Ccp4Header(filename, readHeader=True)
@@ -215,13 +214,13 @@ def convertMicrographs(micList, micDir):
     in a format that is compatible with crYOLO.
     """
     ih = ImageHandler()
-    ext = getExt(micList[0].getFileName())
+    ext = pwutils.getExt(micList[0].getFileName())
 
     def _convert(mic, newName):
         ih.convert(mic, os.path.join(micDir, newName))
 
     def _link(mic, newName):
-        createAbsLink(os.path.abspath(mic.getFileName()),
+        pwutils.createAbsLink(os.path.abspath(mic.getFileName()),
                               os.path.join(micDir, newName))
 
     if ext in constants.CRYOLO_SUPPORTED_FORMATS:
