@@ -26,19 +26,22 @@
 # **************************************************************************
 
 import os
-from pyworkflow.em import ImageHandler, copyFile, ProtImportMicrographs, ProtImportCoordinates
-from pyworkflow.em.convert import Ccp4Header
+
+import pyworkflow.utils as pwutils
 from pyworkflow import Config
 from pyworkflow.tests import (BaseTest, setupTestProject, DataSet, setupTestOutput)
+from pyworkflow.plugin import Domain
 
-import pyworkflow.em.data as emobj
-from pyworkflow.utils import importFromPlugin, makePath
+import pwem.objects as emobj
+from pwem.protocols.protocol_import import ProtImportMicrographs, ProtImportCoordinates
+from pwem.emlib.image import ImageHandler
+from pwem.convert import Ccp4Header
 
 import sphire.convert as convert
 import sphire.protocols as protocols
 from sphire.constants import INPUT_MODEL_OTHER, INPUT_MODEL_GENERAL_NS, CRYOLO_GENMOD_VAR
 
-XmippProtPreprocessMicrographs = importFromPlugin(
+XmippProtPreprocessMicrographs = Domain.importFromPlugin(
     'xmipp3.protocols', 'XmippProtPreprocessMicrographs', doRaise=True)
 
 
@@ -56,7 +59,7 @@ class TestSphireConvert(BaseTest):
     def testConvertCoords(self):
         boxSize = 100
         boxDir = self.getOutputPath('boxDir')
-        makePath(boxDir)
+        pwutils.makePath(boxDir)
 
         def _convert(coordsIn, yFlipHeight=None):
             tmpFile = os.path.join(boxDir, 'tmp.cbox')
@@ -141,7 +144,7 @@ class TestSphireConvert(BaseTest):
         os.mkdir(boxFolder)
 
         micFolder = self.getOutputPath('micFolder')
-        makePath(micFolder)
+        pwutils.makePath(micFolder)
 
         # Invoke the write set of coordinates method
         convert.writeSetOfCoordinates(boxFolder, coordSet)
@@ -182,7 +185,7 @@ class TestSphireConvert(BaseTest):
         # Test right ispg value (0 in mrc file)
         # Copy 006
         goodMrc = self.getOutputPath('good_ispg.mrc')
-        copyFile(mrcFile, goodMrc)
+        pwutils.copyFile(mrcFile, goodMrc)
 
         # Change the ISPG value in the file header
         header = Ccp4Header(goodMrc, readHeader=True)
